@@ -6,50 +6,13 @@ no warnings qw(void once uninitialized numeric);
 package Moops::Keyword::Role;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.025';
+our $VERSION   = '0.026';
 
 use Moo;
 use B qw(perlstring);
 extends qw( Moops::Keyword );
 
-around arguments_for_function_parameters => sub
-{
-	require Moops::MethodModifiers;
-	
-	my $orig     = shift;
-	my $class    = shift;
-	my $keywords = $class->$orig(@_);
-	my $reify    = $keywords->{fun}{reify_type};
-	
-	$keywords->{method} = {
-		name                 => 'optional',
-		runtime              => 0,
-		default_arguments    => 1,
-		check_argument_count => 1,
-		check_argument_types => 1,
-		named_parameters     => 1,
-		types                => 1,
-		reify_type           => $reify,
-		attrs                => ':method',
-		shift                => '$self',
-		invocant             => 1,
-	};
-	$keywords->{ lc($_) } = {
-		name                 => 'required',
-		runtime              => 0,
-		default_arguments    => 1,
-		check_argument_count => 1,
-		check_argument_types => 1,
-		named_parameters     => 1,
-		types                => 1,
-		reify_type           => $reify,
-		attrs                => ":$_",
-		shift                => '$self',
-		invocant             => 1,
-	} for qw( Before After Around );
-	
-	return $keywords;
-};
+sub should_support_methods { 1 }
 
 sub arguments_for_moosex_mungehas
 {
@@ -57,20 +20,9 @@ sub arguments_for_moosex_mungehas
 	return qw(eq_1);
 }
 
-around generate_package_setup => sub
-{
-	my $orig = shift;
-	my $self = shift;
-	
-	return (
-		$self->$orig(@_),
-		$self->generate_package_setup_oo,
-	);
-};
-
 my %using = (
 	Moo   => 'use Moo::Role; use MooX::late;',
-	Moose => 'use Moose::Role; use MooseX::FunctionParametersInfo;',
+	Moose => 'use Moose::Role; use MooseX::KavorkaInfo;',
 	Mouse => 'use Mouse::Role;',
 	Tiny  => 'use Role::Tiny;',
 	(
@@ -133,4 +85,14 @@ around version_relationship => sub
 	$_[0] eq 'using' ? !!0 : $self->$next(@_);
 };
 
+around arguments_for_kavorka => sub
+{
+	my $next = shift;
+	my $self = shift;
+	return (
+		$self->$next(@_),
+		qw/ method before after around /,
+	);
+};
+
 1;
